<?php
/**
 * The Header: Logo and main menu
 *
 * @package PANTRY
 * @since PANTRY 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js<?php
	// Class scheme_xxx need in the <html> as context for the <body>!
	echo ' scheme_' . esc_attr( pantry_get_theme_option( 'color_scheme' ) );
?>">

<head>
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<?php
	if ( function_exists( 'wp_body_open' ) ) {
		wp_body_open();
	} else {
		do_action( 'wp_body_open' );
	}
	do_action( 'pantry_action_before_body' );
	?>

	<div class="<?php echo esc_attr( apply_filters( 'pantry_filter_body_wrap_class', 'body_wrap' ) ); ?>" <?php do_action('pantry_action_body_wrap_attributes'); ?>>

		<?php do_action( 'pantry_action_before_page_wrap' ); ?>

		<div class="<?php echo esc_attr( apply_filters( 'pantry_filter_page_wrap_class', 'page_wrap' ) ); ?>" <?php do_action('pantry_action_page_wrap_attributes'); ?>>

			<?php do_action( 'pantry_action_page_wrap_start' ); ?>

			<?php
			$pantry_full_post_loading = ( pantry_is_singular( 'post' ) || pantry_is_singular( 'attachment' ) ) && pantry_get_value_gp( 'action' ) == 'full_post_loading';
			$pantry_prev_post_loading = ( pantry_is_singular( 'post' ) || pantry_is_singular( 'attachment' ) ) && pantry_get_value_gp( 'action' ) == 'prev_post_loading';

			// Don't display the header elements while actions 'full_post_loading' and 'prev_post_loading'
			if ( ! $pantry_full_post_loading && ! $pantry_prev_post_loading ) {

				// Short links to fast access to the content, sidebar and footer from the keyboard
				?>
				<a class="pantry_skip_link skip_to_content_link" href="#content_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'pantry_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to content", 'pantry' ); ?></a>
				<?php if ( pantry_sidebar_present() ) { ?>
				<a class="pantry_skip_link skip_to_sidebar_link" href="#sidebar_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'pantry_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to sidebar", 'pantry' ); ?></a>
				<?php } ?>
				<a class="pantry_skip_link skip_to_footer_link" href="#footer_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'pantry_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to footer", 'pantry' ); ?></a>

				<?php
				do_action( 'pantry_action_before_header' );

				// Header
				$pantry_header_type = pantry_get_theme_option( 'header_type' );
				if ( 'custom' == $pantry_header_type && ! pantry_is_layouts_available() ) {
					$pantry_header_type = 'default';
				}
				get_template_part( apply_filters( 'pantry_filter_get_template_part', "templates/header-" . sanitize_file_name( $pantry_header_type ) ) );

				// Side menu
				if ( in_array( pantry_get_theme_option( 'menu_side' ), array( 'left', 'right' ) ) ) {
					get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/header-navi-side' ) );
				}

				// Mobile menu
				get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/header-navi-mobile' ) );

				do_action( 'pantry_action_after_header' );

			}
			?>

			<?php do_action( 'pantry_action_before_page_content_wrap' ); ?>

			<div class="page_content_wrap<?php
				if ( pantry_is_off( pantry_get_theme_option( 'remove_margins' ) ) ) {
					if ( empty( $pantry_header_type ) ) {
						$pantry_header_type = pantry_get_theme_option( 'header_type' );
					}
					if ( 'custom' == $pantry_header_type && pantry_is_layouts_available() ) {
						$pantry_header_id = pantry_get_custom_header_id();
						if ( $pantry_header_id > 0 ) {
							$pantry_header_meta = pantry_get_custom_layout_meta( $pantry_header_id );
							if ( ! empty( $pantry_header_meta['margin'] ) ) {
								?> page_content_wrap_custom_header_margin<?php
							}
						}
					}
					$pantry_footer_type = pantry_get_theme_option( 'footer_type' );
					if ( 'custom' == $pantry_footer_type && pantry_is_layouts_available() ) {
						$pantry_footer_id = pantry_get_custom_footer_id();
						if ( $pantry_footer_id ) {
							$pantry_footer_meta = pantry_get_custom_layout_meta( $pantry_footer_id );
							if ( ! empty( $pantry_footer_meta['margin'] ) ) {
								?> page_content_wrap_custom_footer_margin<?php
							}
						}
					}
				}
				do_action( 'pantry_action_page_content_wrap_class', $pantry_prev_post_loading );
				?>"<?php
				if ( apply_filters( 'pantry_filter_is_prev_post_loading', $pantry_prev_post_loading ) ) {
					?> data-single-style="<?php echo esc_attr( pantry_get_theme_option( 'single_style' ) ); ?>"<?php
				}
				do_action( 'pantry_action_page_content_wrap_data', $pantry_prev_post_loading );
			?>>
				<?php
				do_action( 'pantry_action_page_content_wrap', $pantry_full_post_loading || $pantry_prev_post_loading );

				// Single posts banner
				if ( apply_filters( 'pantry_filter_single_post_header', pantry_is_singular( 'post' ) || pantry_is_singular( 'attachment' ) ) ) {
					if ( $pantry_prev_post_loading ) {
						if ( pantry_get_theme_option( 'posts_navigation_scroll_which_block' ) != 'article' ) {
							do_action( 'pantry_action_between_posts' );
						}
					}
					// Single post thumbnail and title
					$pantry_path = apply_filters( 'pantry_filter_get_template_part', 'templates/single-styles/' . pantry_get_theme_option( 'single_style' ) );
					if ( pantry_get_file_dir( $pantry_path . '.php' ) != '' ) {
						get_template_part( $pantry_path );
					}
				}

				// Widgets area above page
				$pantry_body_style   = pantry_get_theme_option( 'body_style' );
				$pantry_widgets_name = pantry_get_theme_option( 'widgets_above_page' );
				$pantry_show_widgets = ! pantry_is_off( $pantry_widgets_name ) && is_active_sidebar( $pantry_widgets_name );
				if ( $pantry_show_widgets ) {
					if ( 'fullscreen' != $pantry_body_style ) {
						?>
						<div class="content_wrap">
							<?php
					}
					pantry_create_widgets_area( 'widgets_above_page' );
					if ( 'fullscreen' != $pantry_body_style ) {
						?>
						</div>
						<?php
					}
				}

				// Content area
				do_action( 'pantry_action_before_content_wrap' );
				?>
				<div class="content_wrap<?php echo 'fullscreen' == $pantry_body_style ? '_fullscreen' : ''; ?>">

					<?php do_action( 'pantry_action_content_wrap_start' ); ?>

					<div class="content">
						<?php
						do_action( 'pantry_action_page_content_start' );

						// Skip link anchor to fast access to the content from keyboard
						?>
						<a id="content_skip_link_anchor" class="pantry_skip_link_anchor" href="#"></a>
						<?php
						// Single posts banner between prev/next posts
						if ( ( pantry_is_singular( 'post' ) || pantry_is_singular( 'attachment' ) )
							&& $pantry_prev_post_loading 
							&& pantry_get_theme_option( 'posts_navigation_scroll_which_block' ) == 'article'
						) {
							do_action( 'pantry_action_between_posts' );
						}

						// Widgets area above content
						pantry_create_widgets_area( 'widgets_above_content' );

						do_action( 'pantry_action_page_content_start_text' );
